pub struct AddAmmLiquidity {Show 16 fields
pub owner: Pubkey,
pub amm_pool: Pubkey,
pub amm_position: Pubkey,
pub lp_mint: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub token_a_vault: Pubkey,
pub token_b_vault: Pubkey,
pub user_token_a_account: Pubkey,
pub user_token_b_account: Pubkey,
pub user_lp_token_account: Pubkey,
pub system_program: Pubkey,
pub token_a_program: Pubkey,
pub token_b_program: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
}Expand description
Generated client accounts for AddAmmLiquidity.
Fields
owner: Pubkeyamm_pool: Pubkeyamm_position: Pubkeylp_mint: Pubkeytoken_a_mint: Pubkeytoken_b_mint: Pubkeytoken_a_vault: Pubkeytoken_b_vault: Pubkeyuser_token_a_account: Pubkeyuser_token_b_account: Pubkeyuser_lp_token_account: Pubkeysystem_program: Pubkeytoken_a_program: Pubkeytoken_b_program: Pubkeytoken_program: Pubkeyassociated_token_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddAmmLiquiditywhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddAmmLiquiditywhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddAmmLiquidity
impl ToAccountMetas for AddAmmLiquidity
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddAmmLiquidity
impl RefUnwindSafe for AddAmmLiquidity
impl Send for AddAmmLiquidity
impl Sync for AddAmmLiquidity
impl Unpin for AddAmmLiquidity
impl UnwindSafe for AddAmmLiquidity