pub struct CreateAmmPool {Show 15 fields
pub payer: Pubkey,
pub authority: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub amm_pool: Pubkey,
pub lp_mint: Pubkey,
pub token_a_vault: Pubkey,
pub token_b_vault: Pubkey,
pub protocol_fee_vault_a: Pubkey,
pub protocol_fee_vault_b: Pubkey,
pub system_program: Pubkey,
pub token_a_program: Pubkey,
pub token_b_program: Pubkey,
pub token_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for CreateAmmPool.
Fields
payer: Pubkeytoken_a_mint: Pubkeytoken_b_mint: Pubkeyamm_pool: Pubkeylp_mint: Pubkeytoken_a_vault: Pubkeytoken_b_vault: Pubkeyprotocol_fee_vault_a: Pubkeyprotocol_fee_vault_b: Pubkeysystem_program: Pubkeytoken_a_program: Pubkeytoken_b_program: Pubkeytoken_program: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateAmmPoolwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateAmmPoolwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateAmmPool
impl ToAccountMetas for CreateAmmPool
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateAmmPool
impl RefUnwindSafe for CreateAmmPool
impl Send for CreateAmmPool
impl Sync for CreateAmmPool
impl Unpin for CreateAmmPool
impl UnwindSafe for CreateAmmPool