pub struct CreateDlmmCommunityPool {Show 14 fields
pub payer: Pubkey,
pub authority: Pubkey,
pub dlmm_parameters: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub dlmm_pool: Pubkey,
pub token_a_vault: Pubkey,
pub token_b_vault: Pubkey,
pub protocol_fee_vault_a: Pubkey,
pub protocol_fee_vault_b: Pubkey,
pub system_program: Pubkey,
pub token_a_program: Pubkey,
pub token_b_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for CreateDlmmCommunityPool.
Fields
payer: Pubkeydlmm_parameters: Pubkeytoken_a_mint: Pubkeytoken_b_mint: Pubkeydlmm_pool: Pubkeytoken_a_vault: Pubkeytoken_b_vault: Pubkeyprotocol_fee_vault_a: Pubkeyprotocol_fee_vault_b: Pubkeysystem_program: Pubkeytoken_a_program: Pubkeytoken_b_program: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateDlmmCommunityPoolwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateDlmmCommunityPoolwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateDlmmCommunityPool
impl ToAccountMetas for CreateDlmmCommunityPool
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateDlmmCommunityPool
impl RefUnwindSafe for CreateDlmmCommunityPool
impl Send for CreateDlmmCommunityPool
impl Sync for CreateDlmmCommunityPool
impl Unpin for CreateDlmmCommunityPool
impl UnwindSafe for CreateDlmmCommunityPool