pub struct CreateDlmmPool {Show 15 fields
pub payer: Pubkey,
pub authority: Pubkey,
pub protocol_config: Pubkey,
pub dlmm_parameters: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub dlmm_pool: Pubkey,
pub token_a_vault: Pubkey,
pub token_b_vault: Pubkey,
pub protocol_fee_vault_a: Pubkey,
pub protocol_fee_vault_b: Pubkey,
pub system_program: Pubkey,
pub token_a_program: Pubkey,
pub token_b_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for CreateDlmmPool.
Fields
payer: Pubkeyprotocol_config: Pubkeydlmm_parameters: Pubkeytoken_a_mint: Pubkeytoken_b_mint: Pubkeydlmm_pool: Pubkeytoken_a_vault: Pubkeytoken_b_vault: Pubkeyprotocol_fee_vault_a: Pubkeyprotocol_fee_vault_b: Pubkeysystem_program: Pubkeytoken_a_program: Pubkeytoken_b_program: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateDlmmPoolwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateDlmmPoolwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateDlmmPool
impl ToAccountMetas for CreateDlmmPool
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateDlmmPool
impl RefUnwindSafe for CreateDlmmPool
impl Send for CreateDlmmPool
impl Sync for CreateDlmmPool
impl Unpin for CreateDlmmPool
impl UnwindSafe for CreateDlmmPool