pub struct DlmmModifyLiquidity {Show 13 fields
pub owner: Pubkey,
pub dlmm_pool: Pubkey,
pub old_position: Pubkey,
pub new_position: Pubkey,
pub transaction_bins: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub user_token_a_account: Pubkey,
pub user_token_b_account: Pubkey,
pub token_a_vault: Pubkey,
pub token_b_vault: Pubkey,
pub token_a_program: Pubkey,
pub token_b_program: Pubkey,
}Expand description
Generated client accounts for DlmmModifyLiquidity.
Fields
owner: Pubkeydlmm_pool: Pubkeyold_position: Pubkeynew_position: Pubkeytransaction_bins: PubkeyThe temporary account holding the pubkeys of all bins for both old and new positions.
token_a_mint: Pubkeytoken_b_mint: Pubkeyuser_token_a_account: Pubkeyuser_token_b_account: Pubkeytoken_a_vault: Pubkeytoken_b_vault: Pubkeytoken_a_program: Pubkeytoken_b_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for DlmmModifyLiquiditywhere
Pubkey: BorshSerialize,
impl BorshSerialize for DlmmModifyLiquiditywhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for DlmmModifyLiquidity
impl ToAccountMetas for DlmmModifyLiquidity
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for DlmmModifyLiquidity
impl RefUnwindSafe for DlmmModifyLiquidity
impl Send for DlmmModifyLiquidity
impl Sync for DlmmModifyLiquidity
impl Unpin for DlmmModifyLiquidity
impl UnwindSafe for DlmmModifyLiquidity