pub struct InitializeDlmmParameters {
pub dlmm_parameters: Pubkey,
pub authority: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitializeDlmmParameters.
Fields
dlmm_parameters: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeDlmmParameterswhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeDlmmParameterswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializeDlmmParameters
impl ToAccountMetas for InitializeDlmmParameters
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeDlmmParameters
impl RefUnwindSafe for InitializeDlmmParameters
impl Send for InitializeDlmmParameters
impl Sync for InitializeDlmmParameters
impl Unpin for InitializeDlmmParameters
impl UnwindSafe for InitializeDlmmParameters