pub struct OpenAmmPosition {
pub owner: Pubkey,
pub amm_pool: Pubkey,
pub amm_position: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for OpenAmmPosition.
Fields
owner: Pubkeyamm_pool: Pubkeyamm_position: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for OpenAmmPositionwhere
Pubkey: BorshSerialize,
impl BorshSerialize for OpenAmmPositionwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for OpenAmmPosition
impl ToAccountMetas for OpenAmmPosition
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for OpenAmmPosition
impl RefUnwindSafe for OpenAmmPosition
impl Send for OpenAmmPosition
impl Sync for OpenAmmPosition
impl Unpin for OpenAmmPosition
impl UnwindSafe for OpenAmmPosition