pub struct UpdateFeePreference {
pub owner: Pubkey,
pub amm_pool: Pubkey,
pub amm_position: Pubkey,
}Expand description
Generated client accounts for UpdateFeePreference.
Fields
owner: Pubkeyamm_pool: Pubkeyamm_position: PubkeyTrait Implementations
Sourceimpl BorshSerialize for UpdateFeePreferencewhere
Pubkey: BorshSerialize,
impl BorshSerialize for UpdateFeePreferencewhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for UpdateFeePreference
impl ToAccountMetas for UpdateFeePreference
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for UpdateFeePreference
impl RefUnwindSafe for UpdateFeePreference
impl Send for UpdateFeePreference
impl Sync for UpdateFeePreference
impl Unpin for UpdateFeePreference
impl UnwindSafe for UpdateFeePreference