AmmPool

Struct AmmPool 

pub struct AmmPool {
Show 21 fields pub bump: u8, pub authority: Pubkey, pub token_a_mint: Pubkey, pub token_b_mint: Pubkey, pub token_a_vault: Pubkey, pub token_b_vault: Pubkey, pub lp_mint: Pubkey, pub fee_rate: u16, pub protocol_fee_share: u16, pub referrer_fee_share: u16, pub protocol_fee_vault_a: Pubkey, pub protocol_fee_vault_b: Pubkey, pub reserves_a: u64, pub reserves_b: u64, pub fee_growth_per_lp_token_a: u128, pub fee_growth_per_lp_token_b: u128, pub price_a_cumulative: u128, pub price_b_cumulative: u128, pub last_update_timestamp: i64, pub last_fee_update_timestamp: i64, pub price_a_cumulative_last_fee_update: u128,
}
State for a permissionless, constant-product AMM pool.

Follows the x * y = k model.

Fields

bump: u8

The PDA bump.

authority: Pubkey

The authority that can update protocol fees or other admin-only parameters. Can be a multi-sig or DAO.

token_a_mint: Pubkeytoken_b_mint: Pubkeytoken_a_vault: Pubkeytoken_b_vault: Pubkeylp_mint: Pubkeyfee_rate: u16protocol_fee_share: u16referrer_fee_share: u16protocol_fee_vault_a: Pubkeyprotocol_fee_vault_b: Pubkeyreserves_a: u64reserves_b: u64fee_growth_per_lp_token_a: u128

Total fees of token A accrued per LP token.

fee_growth_per_lp_token_b: u128

Total fees of token B accrued per LP token.

price_a_cumulative: u128

The cumulative price of token A in terms of token B.

price_b_cumulative: u128

The cumulative price of token B in terms of token A.

last_update_timestamp: i64

The timestamp of the last update to the reserves and oracle.

last_fee_update_timestamp: i64price_a_cumulative_last_fee_update: u128

Snapshot of the cumulative price at the last fee update, used for volatility calculation.