pub struct CreateDlmmPoolBumps {
pub protocol_config: u8,
pub dlmm_parameters: u8,
pub dlmm_pool: u8,
pub token_a_vault: u8,
pub token_b_vault: u8,
pub protocol_fee_vault_a: u8,
pub protocol_fee_vault_b: u8,
}Fields
protocol_config: u8dlmm_parameters: u8dlmm_pool: u8token_a_vault: u8token_b_vault: u8protocol_fee_vault_a: u8protocol_fee_vault_b: u8Trait Implementations
Sourceimpl<'info> Accounts<'info, CreateDlmmPoolBumps> for CreateDlmmPool<'info>where
'info: 'info,
impl<'info> Accounts<'info, CreateDlmmPoolBumps> for CreateDlmmPool<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut CreateDlmmPoolBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut CreateDlmmPoolBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl Debug for CreateDlmmPoolBumps
impl Debug for CreateDlmmPoolBumps