pub struct Position {
pub pool: Pubkey,
pub owner: Pubkey,
pub lower_bin_id: i32,
pub upper_bin_id: i32,
pub liquidity: u128,
pub position_mint: Pubkey,
pub fee_growth_snapshot_a: u128,
pub fee_growth_snapshot_b: u128,
}Fields
pool: Pubkeyowner: Pubkeylower_bin_id: i32upper_bin_id: i32liquidity: u128position_mint: Pubkeyfee_growth_snapshot_a: u128fee_growth_snapshot_b: u128Trait Implementations
Sourceimpl AccountDeserialize for Position
impl AccountDeserialize for Position
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for Position
impl AccountSerialize for Position
Sourceimpl BorshDeserialize for Position
impl BorshDeserialize for Position
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Position
impl BorshSerialize for Position
Sourceimpl Discriminator for Position
impl Discriminator for Position
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more