pub struct AmmLiquidityAdded {
pub pool_address: Pubkey,
pub user: Pubkey,
pub lp_tokens_minted: u64,
pub amount_a_deposited: u64,
pub amount_b_deposited: u64,
}Fields
pool_address: Pubkeyuser: Pubkeylp_tokens_minted: u64amount_a_deposited: u64amount_b_deposited: u64Trait Implementations
Sourceimpl BorshDeserialize for AmmLiquidityAdded
impl BorshDeserialize for AmmLiquidityAdded
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AmmLiquidityAdded
impl BorshSerialize for AmmLiquidityAdded
Sourceimpl Discriminator for AmmLiquidityAdded
impl Discriminator for AmmLiquidityAdded
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more