pub struct AmmSwap {
pub pool_address: Pubkey,
pub trader: Pubkey,
pub input_mint: Pubkey,
pub output_mint: Pubkey,
pub amount_in: u64,
pub amount_out: u64,
pub protocol_fee: u64,
pub lp_fee: u64,
pub referrer: Option<Pubkey>,
}Fields
pool_address: Pubkeytrader: Pubkeyinput_mint: Pubkeyoutput_mint: Pubkeyamount_in: u64amount_out: u64protocol_fee: u64lp_fee: u64referrer: Option<Pubkey>Trait Implementations
Sourceimpl BorshDeserialize for AmmSwap
impl BorshDeserialize for AmmSwap
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for AmmSwap
impl BorshSerialize for AmmSwap
Sourceimpl Discriminator for AmmSwap
impl Discriminator for AmmSwap
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more