pub struct DlmmFeesUpdated {
pub pool_address: Pubkey,
pub new_fee_rate: u16,
}Fields
pool_address: Pubkeynew_fee_rate: u16Trait Implementations
Sourceimpl BorshDeserialize for DlmmFeesUpdated
impl BorshDeserialize for DlmmFeesUpdated
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmFeesUpdated
impl BorshSerialize for DlmmFeesUpdated
Sourceimpl Discriminator for DlmmFeesUpdated
impl Discriminator for DlmmFeesUpdated
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more