pub struct DlmmLiquidityModified {
pub owner: Pubkey,
pub pool_address: Pubkey,
pub old_position_address: Pubkey,
pub new_position_address: Pubkey,
pub liquidity_to_move: u128,
pub surplus_a_out: u64,
pub surplus_b_out: u64,
}Fields
owner: Pubkeypool_address: Pubkeyold_position_address: Pubkeynew_position_address: Pubkeyliquidity_to_move: u128surplus_a_out: u64surplus_b_out: u64Trait Implementations
Sourceimpl BorshDeserialize for DlmmLiquidityModified
impl BorshDeserialize for DlmmLiquidityModified
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for DlmmLiquidityModified
impl Discriminator for DlmmLiquidityModified
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more