pub struct DlmmLiquidityUpdate {
pub position_address: Pubkey,
pub liquidity_added: i128,
pub amount_a: u64,
pub amount_b: u64,
}Fields
position_address: Pubkeyliquidity_added: i128amount_a: u64amount_b: u64Trait Implementations
Sourceimpl BorshDeserialize for DlmmLiquidityUpdate
impl BorshDeserialize for DlmmLiquidityUpdate
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmLiquidityUpdate
impl BorshSerialize for DlmmLiquidityUpdate
Sourceimpl Discriminator for DlmmLiquidityUpdate
impl Discriminator for DlmmLiquidityUpdate
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more