pub struct DlmmPoolCreated {
pub pool_address: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub bin_step: u16,
pub fee_rate: u16,
}Fields
pool_address: Pubkeytoken_a_mint: Pubkeytoken_b_mint: Pubkeybin_step: u16fee_rate: u16Trait Implementations
Sourceimpl BorshDeserialize for DlmmPoolCreated
impl BorshDeserialize for DlmmPoolCreated
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmPoolCreated
impl BorshSerialize for DlmmPoolCreated
Sourceimpl Discriminator for DlmmPoolCreated
impl Discriminator for DlmmPoolCreated
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more