pub struct DlmmPositionOpened {
pub pool_address: Pubkey,
pub owner: Pubkey,
pub position_address: Pubkey,
pub position_mint: Pubkey,
pub lower_bin_id: i32,
pub upper_bin_id: i32,
}Fields
pool_address: Pubkeyowner: Pubkeyposition_address: Pubkeyposition_mint: Pubkeylower_bin_id: i32upper_bin_id: i32Trait Implementations
Sourceimpl BorshDeserialize for DlmmPositionOpened
impl BorshDeserialize for DlmmPositionOpened
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmPositionOpened
impl BorshSerialize for DlmmPositionOpened
Sourceimpl Discriminator for DlmmPositionOpened
impl Discriminator for DlmmPositionOpened
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more