Module instruction

Module instruction 

An Anchor generated module containing the program’s set of instructions, where each method handler in the #[program] mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when specifying instructions on a client.

Structs

AddAmmLiquidity
Instruction.
ClaimLpFees
Instruction.
CreateAmmPool
Instruction.
CreateDlmmCommunityPool
Instruction.
CreateDlmmPool
Instruction.
DlmmAddLiquidity
Instruction.
DlmmBurnEmptyPosition
Instruction.
DlmmModifyLiquidity
Instruction.
DlmmOpenPosition
Instruction.
DlmmRemoveLiquidity
Instruction.
DlmmSwap
Instruction.
InitializeDlmmParameters
Instruction.
InitializeProtocol
Instruction.
OpenAmmPosition
Instruction.
ReinvestLpFees
Instruction.
RemoveAmmLiquidity
Instruction.
SwapOnAmm
Instruction.
UpdateAmmFees
Instruction.
UpdateDlmmFees
Instruction.
UpdateDlmmParameters
Instruction.
UpdateFeePreference
Instruction.