pub struct CreateAmmPool {
pub fee_rate: u16,
pub protocol_fee_share: u16,
pub referrer_fee_share: u16,
}Expand description
Instruction.
Fields
fee_rate: u16Trait Implementations
Sourceimpl BorshDeserialize for CreateAmmPoolwhere
u16: BorshDeserialize,
impl BorshDeserialize for CreateAmmPoolwhere
u16: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateAmmPoolwhere
u16: BorshSerialize,
impl BorshSerialize for CreateAmmPoolwhere
u16: BorshSerialize,
Sourceimpl Discriminator for CreateAmmPool
impl Discriminator for CreateAmmPool
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CreateAmmPool
impl InstructionData for CreateAmmPool