pub struct CreateDlmmCommunityPool {
pub bin_step: u16,
pub fee_rate: u16,
pub protocol_fee_share: u16,
pub referrer_fee_share: u16,
pub initial_bin_id: i32,
}Expand description
Instruction.
Fields
bin_step: u16fee_rate: u16initial_bin_id: i32Trait Implementations
Sourceimpl BorshDeserialize for CreateDlmmCommunityPool
impl BorshDeserialize for CreateDlmmCommunityPool
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for CreateDlmmCommunityPool
impl Discriminator for CreateDlmmCommunityPool
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more