pub struct DlmmAddLiquidity {
pub start_bin_id: i32,
pub liquidity_per_bin: u128,
}Expand description
Instruction.
Fields
start_bin_id: i32liquidity_per_bin: u128Trait Implementations
Sourceimpl BorshDeserialize for DlmmAddLiquidity
impl BorshDeserialize for DlmmAddLiquidity
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmAddLiquidity
impl BorshSerialize for DlmmAddLiquidity
Sourceimpl Discriminator for DlmmAddLiquidity
impl Discriminator for DlmmAddLiquidity
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for DlmmAddLiquidity
impl InstructionData for DlmmAddLiquidity