pub struct DlmmModifyLiquidity {
pub min_surplus_a_out: u64,
pub min_surplus_b_out: u64,
}Expand description
Instruction.
Fields
min_surplus_a_out: u64min_surplus_b_out: u64Trait Implementations
Sourceimpl BorshDeserialize for DlmmModifyLiquiditywhere
u64: BorshDeserialize,
impl BorshDeserialize for DlmmModifyLiquiditywhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmModifyLiquiditywhere
u64: BorshSerialize,
impl BorshSerialize for DlmmModifyLiquiditywhere
u64: BorshSerialize,
Sourceimpl Discriminator for DlmmModifyLiquidity
impl Discriminator for DlmmModifyLiquidity
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more