pub struct DlmmOpenPosition {
pub lower_bin_id: i32,
pub upper_bin_id: i32,
}Expand description
Instruction.
Fields
lower_bin_id: i32upper_bin_id: i32Trait Implementations
Sourceimpl BorshDeserialize for DlmmOpenPositionwhere
i32: BorshDeserialize,
impl BorshDeserialize for DlmmOpenPositionwhere
i32: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmOpenPositionwhere
i32: BorshSerialize,
impl BorshSerialize for DlmmOpenPositionwhere
i32: BorshSerialize,
Sourceimpl Discriminator for DlmmOpenPosition
impl Discriminator for DlmmOpenPosition
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for DlmmOpenPosition
impl InstructionData for DlmmOpenPosition