pub struct DlmmRemoveLiquidity {
pub liquidity_to_remove: u128,
pub min_amount_a: u64,
pub min_amount_b: u64,
}Expand description
Instruction.
Fields
liquidity_to_remove: u128min_amount_a: u64min_amount_b: u64Trait Implementations
Sourceimpl BorshDeserialize for DlmmRemoveLiquidity
impl BorshDeserialize for DlmmRemoveLiquidity
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for DlmmRemoveLiquidity
impl BorshSerialize for DlmmRemoveLiquidity
Sourceimpl Discriminator for DlmmRemoveLiquidity
impl Discriminator for DlmmRemoveLiquidity
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more