pub struct InitializeDlmmParameters {
pub official_params: Vec<DlmmParameter>,
pub community_params: Vec<DlmmParameter>,
}Expand description
Instruction.
Fields
official_params: Vec<DlmmParameter>community_params: Vec<DlmmParameter>Trait Implementations
Sourceimpl BorshDeserialize for InitializeDlmmParameters
impl BorshDeserialize for InitializeDlmmParameters
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for InitializeDlmmParameters
impl Discriminator for InitializeDlmmParameters
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more