pub struct OpenAmmPosition {
pub fee_preference: FeePreference,
}Expand description
Instruction.
Fields
fee_preference: FeePreferenceTrait Implementations
Sourceimpl BorshDeserialize for OpenAmmPositionwhere
FeePreference: BorshDeserialize,
impl BorshDeserialize for OpenAmmPositionwhere
FeePreference: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OpenAmmPositionwhere
FeePreference: BorshSerialize,
impl BorshSerialize for OpenAmmPositionwhere
FeePreference: BorshSerialize,
Sourceimpl Discriminator for OpenAmmPosition
impl Discriminator for OpenAmmPosition
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for OpenAmmPosition
impl InstructionData for OpenAmmPosition