pub struct RemoveAmmLiquidity {
pub lp_tokens_to_burn: u64,
pub min_amount_a_to_receive: u64,
pub min_amount_b_to_receive: u64,
}Expand description
Instruction.
Fields
lp_tokens_to_burn: u64min_amount_a_to_receive: u64min_amount_b_to_receive: u64Trait Implementations
Sourceimpl BorshDeserialize for RemoveAmmLiquiditywhere
u64: BorshDeserialize,
impl BorshDeserialize for RemoveAmmLiquiditywhere
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RemoveAmmLiquiditywhere
u64: BorshSerialize,
impl BorshSerialize for RemoveAmmLiquiditywhere
u64: BorshSerialize,
Sourceimpl Discriminator for RemoveAmmLiquidity
impl Discriminator for RemoveAmmLiquidity
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for RemoveAmmLiquidity
impl InstructionData for RemoveAmmLiquidity