pub struct UpdateDlmmFees {
pub new_fee_rate: Option<u16>,
}Expand description
Instruction.
Fields
new_fee_rate: Option<u16>Trait Implementations
Sourceimpl BorshDeserialize for UpdateDlmmFees
impl BorshDeserialize for UpdateDlmmFees
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for UpdateDlmmFees
impl BorshSerialize for UpdateDlmmFees
Sourceimpl Discriminator for UpdateDlmmFees
impl Discriminator for UpdateDlmmFees
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for UpdateDlmmFees
impl InstructionData for UpdateDlmmFees