pub struct UpdateDlmmParameters {
pub list: ParameterList,
pub action: ParameterAction,
pub bin_step: u16,
pub fee_rate: u16,
}Expand description
Instruction.
Fields
list: ParameterListaction: ParameterActionbin_step: u16fee_rate: u16Trait Implementations
Sourceimpl BorshDeserialize for UpdateDlmmParameters
impl BorshDeserialize for UpdateDlmmParameters
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Discriminator for UpdateDlmmParameters
impl Discriminator for UpdateDlmmParameters
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more